@@ -7,8 +7,8 @@ TODO:
     - Preset prompts
     - Proxy
 """
-__version__ = '0.2.4'
-__all__ = ['core', 'config', 'convo', 'cli', 'util']
+__version__ = '0.2.6'
+__all__ = ['core', 'config', 'convo', 'cli', 'util', "preset"]
 
 if __name__ == '__main__':
     for module in __all__:
