@@ -5,14 +5,13 @@ import os
 import sys
 from typing import Optional
 
-import openai
 import questionary as q
 from prompt_toolkit.lexers import PygmentsLexer
 
-from cliai.config import create_or_update_config, load_config
+from cliai.config import (auth, create_or_update_config, is_authenticated,
+                          load_config)
 from cliai.convo import MessageList, load_convo, make_request, save_convo
-from cliai.util import (InputLexer, print_not_implemented, print_response,
-                        print_role, print_success, print_warning)
+from cliai.util import InputLexer, print_response, print_role, print_warning
 
 
 def metainitiate():
@@ -21,49 +20,40 @@ def metainitiate():
     """
     create_or_update_config()
     # generate_builtin_convs()
-    pass
 
 
-def initiate(api_key: Optional[str] = None):
+def initiate(api_key: Optional[str] = None,
+             api_base: Optional[str] = None):
     """
-    Function to initiate the CLI application.
+    Function to initiate OpenAI API settings.
     """
-    if api_key:
-        auth(api_key)
-    elif api_env := os.getenv('OPENAI_API_KEY'):
-        auth(api_env)
-    else:
+    args = {'api_key': [api_key, 'OPENAI_API_KEY']}
+            # 'api_base': [api_base, 'OPENAI_API_BASE']}
+
+    if not api_key:
         config = load_config()
-        auth(config.get('api_key'))
+
+    auth_args = {}
+    for arg_str in args.keys():
+        arg = args[arg_str][0]
+
+        # API Key given as cli arg
+        if arg:
+            auth_args[arg_str] = arg
+
+        # API Key as shell var (deprecated)
+        # elif arg_env := os.getenv(args[arg_str][1]):
+        #     auth_args[arg_str] = arg_env
+
+        # API Key from the config
+        else:
+            auth_args[arg_str] = config.get(arg_str)
+
+    auth(**auth_args)
 
     load_convo()
 
 
-def is_authenticated() -> bool:
-    """
-    Check if the user has authenticated with OpenAI.
-    """
-    if openai.api_key:
-        try:
-            return openai.Model.list() is not None
-        except openai.error.AuthenticationError:
-            return False
-    else:
-        return False
-
-
-def auth(api_key: str) -> None:
-    """
-    Authenticate the API key provided by the user.
-    """
-    openai.api_key = api_key
-
-    if is_authenticated():
-        print_success('\tAuthenticated!\n')
-    else:
-        print_warning('Incorrect API key provided!')
-
-
 def converse(messages: Optional[MessageList] = None,
              verbose: Optional[bool] = 0) -> None:
     """
@@ -77,6 +67,10 @@ def converse(messages: Optional[MessageList] = None,
 
     print('Welcome to chat mode.\n')
 
+    # Ask which bot to use
+    # presets_handler: PresetsHandler = PresetsHandler()
+    # preset: Preset = presets_handler.select_preset()
+
     # Ask if to use custom system role
     if not q.confirm('Use the default system role?').ask():
         print()
@@ -94,6 +88,7 @@ def converse(messages: Optional[MessageList] = None,
 
         # Make the resquest while true
         while True:
+            # response = make_request(messages, preset)
             response = make_request(messages)
             finish_reason = response.choices[0].finish_reason
 
@@ -137,6 +132,7 @@ def converse(messages: Optional[MessageList] = None,
                         print_role('System')
                         messages.update_system(q.text('', qmark='', lexer=PygmentsLexer(InputLexer)).ask().strip())
                         print()
+                        break
 
                 elif user_reaction == 'Retry':
                     pass
@@ -150,4 +146,18 @@ def converse(messages: Optional[MessageList] = None,
             elif finish_reason == 'length':
                 q.confirm('Maximum length reached. Retry?').ask()
 
+            elif finish_reason == 'content_filter':
+                print_warning('Content flagged by OpenAI!')
+                q.confirm('Retry?').ask()
+
+            # null
+            else:
+                pass
+
             print()
+
+def manage_config():
+    pass
+
+def manage_convos():
+    pass
