@@ -2,8 +2,7 @@
 # -*- coding: utf-8 -*-
 
 from prompt_toolkit import print_formatted_text as pt_print
-from prompt_toolkit.formatted_text import FormattedText as FText
-from prompt_toolkit.formatted_text import PygmentsTokens
+from prompt_toolkit.formatted_text import PygmentsTokens, FormattedText
 from prompt_toolkit.styles import Style
 from pygments import lex
 from pygments.lexer import RegexLexer
@@ -23,7 +22,7 @@ STYLE_SHEET = Style([
 class ResponseLexer(RegexLexer):
     tokens = {
         'root': [
-            (r'^As\ an\ AI\ language\ model.*?\.', Generic.Deleted),
+            (r'^As\ an\ AI\ language\ model.*?[\.\!]', Generic.Deleted),
             (r'[ ^(]`(.*?)`', Comment.Preproc),
             # TODO: Colour based on language
             (r'^```(.*?$\n)?(.*?\n)+?^```$', Comment.Preproc),
@@ -43,21 +42,22 @@ class InputLexer(RegexLexer):
 
 
 def print_response(response: str) -> None:
-    tokens = PygmentsTokens(list(lex(response.lstrip(), lexer=ResponseLexer())))
+    tokens = PygmentsTokens(list(lex(response.lstrip(),
+                                     lexer=ResponseLexer())))
     pt_print(tokens, style=STYLE_SHEET)
 
 
 def print_role(role: str) -> None:
     # ROLES = ('system', 'assistant', 'user')
-    pt_print(FText([('class:role', f'[{role}]')]), style=STYLE_SHEET)
+    pt_print(FormattedText([('class:role', f'[{role}]')]), style=STYLE_SHEET)
 
 
 def print_warning(text: str) -> None:
-    pt_print(FText([('class:warning', text)]), style=STYLE_SHEET)
+    pt_print(FormattedText([('class:warning', text)]), style=STYLE_SHEET)
 
 
 def print_success(text: str) -> None:
-    pt_print(FText([('class:success', text)]), style=STYLE_SHEET)
+    pt_print(FormattedText([('class:success', text)]), style=STYLE_SHEET)
 
 
 def print_not_implemented() -> None:
